tlslite.messages.ClientHello

Package tlslite :: Module messages :: Class ClientHello |
[show private | hide private]
[frames | no frames]

## Class ClientHello

         Msg --+
               |
    HandshakeMsg --+
                   |
                  ClientHello

Method Summary
| `__init__(self, ssl2)`
| `create(self, version, random, session_id, cipher_suites, certificate_types, srp_username)`
| `parse(self, p)`
| `write(self, trial)`
Inherited from HandshakeMsg
| ``preWrite`(self, handshakeType, trial)`
Inherited from Msg
| ``postWrite`(self, w, trial)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:56 2005 | http://epydoc.sf.net